
;   Example script to produce plots for a WRF real-data run,
;   with the ARW coordinate dynamics option.
;   Plot data on a cross section
;   This script will plot data at a set angle through a specified point

load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/wrf/WRFUserARW.ncl"
;load "WRFUserARW.ncl"

begin
;
; The WRF ARW input file.  
; This needs to have a ".nc" appended, so just do it.
  a = addfile("./wrfoutfile.nc","r")

; We generate plots, but what kind do we prefer?
;  type = "x11"
; type = "pdf"
 type = "ps"
; type = "ncgm"
  wks = gsn_open_wks(type,"plt_CrossSection1")

; Set some Basic Plot options
  ARWres = True
  ARWres@MainTitle                   = "REAL-TIME WRF"

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; What times and how many time steps are in the data set?
  FirstTime = True
  times  = wrf_user_list_times(a)  ; get times in the file
  ntimes = dimsizes(times)         ; number of times in the file

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  do it = 1,ntimes-1,1             ; TIME LOOP

    print("Working on time: " + times(it) )
    ARWres@TimeLabel = times(it)   ; Set Valid time to use on plots

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; First get the variables we will need        

    tc  = wrf_user_getvar(a,"ua",it)     ; T in C
    rh = wrf_user_getvar(a,"wa",it)      ; relative humidity
    z   = wrf_user_getvar(a, "z",it)     ; grid point height

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    if (FirstTime) then
      ; THIS IS NEEDED FOR Y LABLES - ALWAYS DO
      zz = z/100.
      dims = dimsizes(zz) 
      zmax = -999.
      do imax = 0,dims(0)-1
        if ( .not.ismissing(zz(imax,1,1)) .and. zz(imax,1,1) .gt. zmax ) then
          zmax = zz(imax,1,1)
        end if
      end do
      imax = floattoint(zmax)
      zmax = imax/10.
      print("Y labels set to: 0 - " + zmax + " km")
      FirstTime = False
      ; END OF ALWAYS DO
    end if



    do ip = 1, 1      	; we are doing 3 plots
			; all with the pivot point (plane) in the center of the domain
			; at angles 0, 45 and 90
 ;                   |
 ;                   |
 ;       angle=0 is  |, angle=90 is ------
 ;                   |
 ;                   |
        if(ip .eq. 1) then
          angle = 90.
        end if
        if(ip .eq. 2) then
          angle = 0.
        end if
        if(ip .eq. 3) then
          angle = 45.
        end if

  ;   Build plane (pivot point) through which the cross section will go 
  ;   OR set to zero, if start and end points are specified
  ;   IF using plane and angle, set opts in wrf_user_intrp3d to False
        dimsrh = dimsizes(rh)
        plane = new(2,float)
        plane = (/ dimsrh(2)/2, dimsrh(1)/2 /)    ; pivot point is center of domain
        opts = False

        ; Interpolate data vertically (in z)

        rh_plane = wrf_user_intrp3d(rh,z,"v",plane,angle,opts)
        tc_plane = wrf_user_intrp3d(tc,z,"v",plane,angle,opts)
        
  ; Options for XY Plots
        opts_xy                         = ARWres
        opts_xy@tiXAxisString           = "Number of Grid Points"
        opts_xy@tiYAxisString           = "Height (km)"
        opts_xy@cnMissingValPerimOn     = True
        opts_xy@cnMissingValFillColor   = 0
        opts_xy@cnMissingValFillPattern = 11
        opts_xy@tmYLMode                = "Explicit"
        opts_xy@tmYLValues              = ispan(0,100,10) ; over the 0-100 span of the Y label
							  ; we are creating 10+1 tick marks
							  ; 100/10 + 1
        opts_xy@tmYLLabels              = fspan(0,zmax,11); Corresponding 11 labels
        opts_xy@tiXAxisFontHeightF      = 0.020
        opts_xy@tiYAxisFontHeightF      = 0.020
        opts_xy@tmXBMajorLengthF        = 0.02
        opts_xy@tmYLMajorLengthF        = 0.02
        opts_xy@tmYLLabelFontHeightF    = 0.015
        opts_xy@PlotOrientation         = tc_plane@Orientation


  ; Plotting options for RH
        opts_rh = opts_xy
        opts_rh@ContourParameters       = (/ -.1, .1, .005 /)
        opts_rh@cnFillOn                = True
;        opts_rh@cnFillColors            = (/"White","White","White", \
;                                            "White","Chartreuse","Green", \
;                                            "Green3","Green4", \
;                                            "ForestGreen","PaleGreen4"/)
         opts_rh@cnFillColors            = (/\
					   "Brown",\
					   "Brown",\
					    "Red4",\
					    "Red4",\
					    "Red4",\
					    "Red4",\
					    "Red",\
					    "Red",\
					    "Red",\
					    "Red",\
                                            "Yellow4",\
                                            "Yellow4",\
                                            "Yellow4",\
                                            "Yellow4",\
					    "Orange", \
					    "Orange", \
					    "Orange", \
					    "Orange", \
					    "Yellow", \
					    "Yellow", \
					    "White", \
                                            "White",\
                                            "Green",\
                                            "Green",\
					    "Green2", \
					    "Green2", \
					    "Green2", \
					    "Green2", \
                                            "ForestGreen",\
                                            "ForestGreen",\
                                            "ForestGreen",\
                                            "ForestGreen",\
					    "Blue",\
					    "Blue",\
					    "Blue",\
					    "Blue",\
					    "Blue2",\
					    "Blue2",\
					    "Blue2",\
					    "Blue2",\
					    "Violet",\
					    "Violet",\
					    "Violet",\
					    "Violet"/)

  ; Plotting options for Temperature
        opts_tc = opts_xy
        opts_tc@ContourParameters  = (/ 5. /)


  ; Get the contour info for the rh and temp
        contour_tc = wrf_contour(a,wks,tc_plane,opts_tc)
        contour_rh = wrf_contour(a,wks,rh_plane,opts_rh)


  ; MAKE PLOTS         
        ;wrf_overlay(wks,(/contour_rh,contour_tc/),True)
        wrf_overlay(wks,(/contour_rh/),True)

  ; Delete options and fields, so we don't have carry over
        delete(opts_tc)
        delete(opts_rh)
        delete(tc_plane)
        delete(rh_plane)

    end do  ; make next cross section

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  end do        ; END OF TIME LOOP

end
